from distutils.core import setup
setup(
    name="alsobrowsercodelib",
    version="0.1.1",
    description="学而思爱搜浏览器功能库0.1.1，下载失败请切换路线1,©爱搜浏览器团队 版权所有",
    author="asunc",
    author_email="3182305655@qq.com",
    py_modules=["alsobrowsercodelib"]
)